summaryrefslogtreecommitdiffhomepage
path: root/dragon
diff options
context:
space:
mode:
authorSimon Chiang <[email protected]>2021-04-23 11:18:12 -0600
committerAmir Rajan <[email protected]>2021-05-26 16:07:47 -0500
commit0f348fa240ff2bb0fa508368411e6d1fc73e167a (patch)
treee3466e15e191026cc5f2c1debde1a4bd21b5b05a /dragon
parent575b8ce2722d23355b137905e39aaaed2436b0ce (diff)
downloaddragonruby-game-toolkit-contrib-0f348fa240ff2bb0fa508368411e6d1fc73e167a.tar.gz
dragonruby-game-toolkit-contrib-0f348fa240ff2bb0fa508368411e6d1fc73e167a.zip
Fix spelling separator not seperator
Diffstat (limited to 'dragon')
-rw-r--r--dragon/console_prompt.rb10
1 files changed, 5 insertions, 5 deletions
diff --git a/dragon/console_prompt.rb b/dragon/console_prompt.rb
index b97bdba..d4c4026 100644
--- a/dragon/console_prompt.rb
+++ b/dragon/console_prompt.rb
@@ -157,11 +157,11 @@ S
# partition the original list of items into a string to be printed
items.each_slice(columns).each_with_index do |cells, i|
- pretty_print_row_seperator string_width, cell_width, column_width, columns
+ pretty_print_row_separator string_width, cell_width, column_width, columns
pretty_print_row cells, string_width, cell_width, column_width, columns
end
- pretty_print_row_seperator string_width, cell_width, column_width, columns
+ pretty_print_row_separator string_width, cell_width, column_width, columns
end
end
@@ -174,17 +174,17 @@ S
"#{" " * (string_width.length - c.length) } #{c} |"
end.join
- # remove seperators between empty values
+ # remove separators between empty values
formated_row = formated_row.gsub(" | ", " ")
puts formated_row
end
- def pretty_print_row_seperator string_width, cell_width, column_width, columns
+ def pretty_print_row_separator string_width, cell_width, column_width, columns
# this is a joint: +--------
column_joint = "+#{"-" * cell_width}"
# multiple joints create a row seperator: +----+----+
puts (column_joint * columns) + "+"
end
@@ -174,17 +174,17 @@ S
# this is a joint: +--------
column_joint = "+#{"-" * cell_width}"
- # multiple joints create a row seperator: +----+----+
+ # multiple joints create a row separator: +----+----+
puts (column_joint * columns) + "+"
end